[Initng-svn] r2970 - in initng/plugins: also chroot conflict cpout
critical cron daemon daemon_clean empty envparser ezxmlparser
find fstat history idleprobe inetd initctl interactive
iparser justbeforeX last limit netprobe ngc2 ngcs pause
pidfile provide reload respawn rlparser service
simple_launcher splash stcmd stdout syncron syslog unneeded usplash
svn at initng.thinktux.net
svn at initng.thinktux.net
Wed Feb 8 08:49:34 CET 2006
Author: thelich
Date: Wed Feb 8 08:49:31 2006
New Revision: 2970
Modified:
initng/plugins/also/initng_also.c
initng/plugins/also/initng_also.h
initng/plugins/chroot/initng_chroot.c
initng/plugins/conflict/initng_conflict.c
initng/plugins/conflict/initng_conflict.h
initng/plugins/cpout/initng_colorprint_out.c
initng/plugins/critical/initng_critical.c
initng/plugins/critical/initng_critical.h
initng/plugins/cron/initng_cron.c
initng/plugins/cron/initng_cron.h
initng/plugins/daemon/initng_daemon.c
initng/plugins/daemon/initng_daemon.h
initng/plugins/daemon_clean/initng_daemon_clean.c
initng/plugins/daemon_clean/initng_daemon_clean.h
initng/plugins/empty/initng_empty.c
initng/plugins/empty/initng_empty.h
initng/plugins/envparser/initng_envparser.c
initng/plugins/ezxmlparser/ezxml.c
initng/plugins/ezxmlparser/initng_ezxml_parser.c
initng/plugins/ezxmlparser/initng_ezxml_parser.h
initng/plugins/find/initng_find.c
initng/plugins/fstat/initng_fstat.c
initng/plugins/fstat/initng_fstat.h
initng/plugins/history/initng_history.c
initng/plugins/idleprobe/initng_idleprobe.c
initng/plugins/idleprobe/initng_idleprobe.h
initng/plugins/inetd/initng_inetd.c
initng/plugins/initctl/initng_initctl.c
initng/plugins/initctl/initreq.h
initng/plugins/interactive/initng_interactive.c
initng/plugins/interactive/initng_interactive.h
initng/plugins/iparser/initng_i_parser.c
initng/plugins/justbeforeX/initng_jbx.c
initng/plugins/justbeforeX/initng_jbx.h
initng/plugins/last/initng_last.c
initng/plugins/last/initng_last.h
initng/plugins/limit/initng_limit.c
initng/plugins/netprobe/initng_netprobe.c
initng/plugins/netprobe/initng_netprobe.h
initng/plugins/ngc2/initng_ngc2.c
initng/plugins/ngc2/initng_ngc2.h
initng/plugins/ngc2/ngc2.c
initng/plugins/ngcs/initng_ngcs.c
initng/plugins/pause/initng_pause.c
initng/plugins/pidfile/initng_pidfile.c
initng/plugins/provide/initng_provide.c
initng/plugins/provide/initng_provide.h
initng/plugins/reload/initng_reload.c
initng/plugins/reload/initng_reload.h
initng/plugins/respawn/initng_respawn.c
initng/plugins/respawn/initng_respawn.h
initng/plugins/rlparser/initng_rl_parser.c
initng/plugins/service/initng_service.c
initng/plugins/service/initng_service.h
initng/plugins/simple_launcher/initng_simple_launcher.c
initng/plugins/splash/initng_splash.c
initng/plugins/stcmd/initng_stcmd.c
initng/plugins/stcmd/print_service.c
initng/plugins/stdout/initng_stdout.c
initng/plugins/syncron/initng_syncron.c
initng/plugins/syncron/initng_syncron.h
initng/plugins/syslog/initng_syslog.c
initng/plugins/unneeded/initng_unneeded.c
initng/plugins/usplash/initng_usplash.c
Log:
major spellchecking (plugins)
Modified: initng/plugins/also/initng_also.c
==============================================================================
--- initng/plugins/also/initng_also.c (original)
+++ initng/plugins/also/initng_also.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -68,7 +68,7 @@
}
/* HACK WARNING
- * service name starting with "virtual/" is no idea to start, sience
+ * service name starting with "virtual/" is no idea to start, since
* they wont exists anyway, this is a waist of resources.
*/
if (strncmp(fixed, "virtual/", 8) == 0)
@@ -89,7 +89,7 @@
return (TRUE);
}
- /* if this service is stopping, stopp all in ALSO_STOP */
+ /* if this service is stopping, stop all in ALSO_STOP */
if (IS_STOPPING(service))
{
/* Handle ALSO_STOP */
Modified: initng/plugins/also/initng_also.h
==============================================================================
--- initng/plugins/also/initng_also.h (original)
+++ initng/plugins/also/initng_also.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/chroot/initng_chroot.c
==============================================================================
--- initng/plugins/chroot/initng_chroot.c (original)
+++ initng/plugins/chroot/initng_chroot.c Wed Feb 8 08:49:31 2006
@@ -35,7 +35,7 @@
#include <assert.h>
s_entry CHROOT = { "chroot", STRING, NULL,
- "Chroot this path, befor launching the service."
+ "Chroot this path, before launching the service."
};
int do_chroot(active_db_h * s, process_h * p __attribute__ ((unused)))
Modified: initng/plugins/conflict/initng_conflict.c
==============================================================================
--- initng/plugins/conflict/initng_conflict.c (original)
+++ initng/plugins/conflict/initng_conflict.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/conflict/initng_conflict.h
==============================================================================
--- initng/plugins/conflict/initng_conflict.h (original)
+++ initng/plugins/conflict/initng_conflict.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/cpout/initng_colorprint_out.c
==============================================================================
--- initng/plugins/cpout/initng_colorprint_out.c (original)
+++ initng/plugins/cpout/initng_colorprint_out.c Wed Feb 8 08:49:31 2006
@@ -129,7 +129,7 @@
if (IS_STARTING(service))
{
- /* if we print this on boot, we clutter up the screen to mutch */
+ /* if we print this on boot, we clutter up the screen too much */
if (g.sys_state == STATE_STARTING)
return (TRUE);
clear_lastserv();
@@ -157,7 +157,7 @@
if (IS_STOPPING(service))
{
/*
- * dont prompt that we are stopping a service, if system is shuting down, i
+ * don't prompt that we are stopping a service, if system is shutting down, i
* do think that the user is aware about this.
*/
if (g.sys_state == STATE_STOPPING)
@@ -242,7 +242,7 @@
static int print_program_output(active_db_h * service, process_h * x)
{
/*
- Todo here:
+ TODO here:
we should have an internal list of services and "our" current position in them.
That way when this function is called we can print every full line from plugin_pos.
@@ -273,7 +273,7 @@
i++;
}
- /* if there are stupid tockens, go to next char, and run while again. */
+ /* if there are stupid tokens, go to next char, and run while again. */
if (x->buffer[i] == ' ' || x->buffer[i] == '\n'
|| x->buffer[i] == '\t')
{
Modified: initng/plugins/critical/initng_critical.c
==============================================================================
--- initng/plugins/critical/initng_critical.c (original)
+++ initng/plugins/critical/initng_critical.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@
#include "initng_critical.h"
s_entry CRITICAL = { "critical", SET, NULL,
- "If this option is set, and service doesn't suceed, initng will quit and offer a sulogin."
+ "If this option is set, and service doesn't succeed, initng will quit and offer a sulogin."
};
/* returns TRUE if all use deps are started */
@@ -46,7 +46,7 @@
assert(service);
assert(service->name);
- /* if critial is set */
+ /* if critical is set */
if (!initng_active_db_is(&CRITICAL, service))
return (TRUE);
Modified: initng/plugins/critical/initng_critical.h
==============================================================================
--- initng/plugins/critical/initng_critical.h (original)
+++ initng/plugins/critical/initng_critical.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/cron/initng_cron.c
==============================================================================
--- initng/plugins/cron/initng_cron.c (original)
+++ initng/plugins/cron/initng_cron.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -154,7 +154,7 @@
static void killed_cron(active_db_h * service, process_h * process)
{
if (process->r_code == 0)
- printf("Cron for service %s, exited sucessfully!\n", service->name);
+ printf("Cron for service %s, exited successfully!\n", service->name);
else
printf("Cron for service %s, exited with r_code %i!\n", service->name,
process->r_code);
Modified: initng/plugins/cron/initng_cron.h
==============================================================================
--- initng/plugins/cron/initng_cron.h (original)
+++ initng/plugins/cron/initng_cron.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/daemon/initng_daemon.c
==============================================================================
--- initng/plugins/daemon/initng_daemon.c (original)
+++ initng/plugins/daemon/initng_daemon.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
@@ -114,17 +114,17 @@
a_state_h DAEMON_START_MARKED = { "DAEMON_START_MARKED", IS_STARTING, &handle_DAEMON_START_MARKED };
/*
- * When we want to stop a DAEMON_RUNNING daemon, its marked SERVIE_STOP_MARKED
+ * When we want to stop a DAEMON_RUNNING daemon, its marked SERVICE_STOP_MARKED
*/
a_state_h DAEMON_STOP_MARKED = { "DAEMON_STOP_MARKED", IS_STOPPING, &handle_DAEMON_STOP_MARKED };
/*
- * When a daemon is UP, it is marked as SERVIVE_DONE
+ * When a daemon is UP, it is marked as SERVICE_DONE
*/
a_state_h DAEMON_RUNNING = { "DAEMON_RUNNING", IS_UP, NULL };
/*
- * When daemons needed by current one is starting, current daemon is set DAEMON_WAITNING_FOR_START_DEP
+ * When daemons needed by current one is starting, current daemon is set DAEMON_WAITING_FOR_START_DEP
*/
a_state_h DAEMON_WAITING_FOR_START_DEP = { "DAEMON_WAITING_FOR_START_DEP", IS_STARTING,
&handle_DAEMON_WAITING_FOR_START_DEP };
@@ -146,7 +146,7 @@
a_state_h DAEMON_STOP_DEPS_MET = { "DAEMON_STOP_DEPS_MET", IS_STARTING, &handle_DAEMON_STOP_DEPS_MET };
/*
- * This markes the daemons, as DOWN.
+ * This marks the daemons, as DOWN.
*/
a_state_h DAEMON_STOPPED = { "DAEMON_STOPPED", IS_DOWN, NULL };
@@ -185,7 +185,7 @@
}
-/* This are run, when initng wats to stop a daemon */
+/* This are run, when initng wants to stop a daemon */
static int stop_DAEMON(active_db_h * daemon)
{
/* set stopping */
@@ -197,7 +197,7 @@
/*
* ############################################################################
- * # PLUGIN INITSIATORS #
+ * # PLUGIN INITIATORS #
* ############################################################################
*/
@@ -270,10 +270,10 @@
static void handle_DAEMON_START_MARKED(active_db_h * daemon)
{
- /* start all our dependencys */
+ /* start all our dependencies */
initng_depend_start_deps(daemon);
- /* TODO, add the dependecy start code here */
+ /* TODO, add the dependency start code here */
initng_common_mark_service(daemon, &DAEMON_WAITING_FOR_START_DEP);
}
@@ -304,7 +304,7 @@
if (initng_depend(daemon, current) == FALSE)
continue;
- /* if servuce dep on is starting, wait a bit */
+ /* if service dep on is starting, wait a bit */
if (IS_STARTING(current))
return;
@@ -319,11 +319,11 @@
}
}
- /* this checks with external plugins, if its ok to start this service now */
+ /* this checks with external plug-ins, if its ok to start this service now */
if(initng_depend_start_dep_met(daemon)!=TRUE)
return;
- /* if system is shuting down, Dont start anything. */
+ /* if system is shutting down, Don't start anything. */
if (g.sys_state != STATE_STARTING && g.sys_state != STATE_UP)
{
F_("Can't start daemon, when system status is: %i !\n", g.sys_state);
@@ -355,7 +355,7 @@
if (initng_depend(current, daemon) == FALSE)
continue;
- /* if its done, this is pefrect */
+ /* if its done, this is perfect */
if (IS_DOWN(current))
continue;
@@ -376,7 +376,7 @@
return;
}
- /* check with other plugins, if it is ok to stop this service now */
+ /* check with other plug-ins, if it is ok to stop this service now */
if(initng_depend_stop_dep_met(daemon)!=TRUE)
return;
@@ -404,7 +404,7 @@
return;
}
- /* We youst set it to up, as soon as it is started */
+ /* We just set it to up, as soon as it is started */
initng_common_mark_service(daemon, &DAEMON_RUNNING);
}
@@ -452,7 +452,7 @@
}
- /* TODO, STOP_TIMEOUT shud be KILL_TIMEOUT */
+ /* TODO, STOP_TIMEOUT should be KILL_TIMEOUT */
if (initng_active_db_is(&STOP_TIMEOUT, service))
{
initng_global_set_sleep(initng_active_db_get_int
@@ -482,7 +482,7 @@
if (current == daemon_stopped)
continue;
- /* DONT stop runlevels OR virtuals */
+ /* DON'T stop runlevels OR virtuals */
if (current->type == &TYPE_VIRTUAL)
continue;
@@ -490,7 +490,7 @@
if (initng_depend(current, daemon_stopped) == FALSE)
continue;
- /* dont stop a stopped daemon */
+ /* don't stop a stopped daemon */
if (IS_DOWN(current))
continue;
@@ -574,7 +574,7 @@
process->pid, service->name);
}
- /* Uhm, this doesnt work : kill(-service->start_process->pid, SIGTERM); */
+ /* Uhm, this doesn't work : kill(-service->start_process->pid, SIGTERM); */
kill(process->pid, SIGTERM);
if (initng_active_db_is(&STOP_TIMEOUT, service))
@@ -593,7 +593,7 @@
/*
* ############################################################################
- * # KILLHANDLER FUNCTIONS #
+ * # KILL HANDLER FUNCTIONS #
* ############################################################################
*/
@@ -608,7 +608,7 @@
D_("handle_killed_start(%s): initial status: \"%s\".\n",
daemon->name, daemon->current_state->state_name);
- /* Set the universal variable, that signalize that something happend */
+ /* Set the universal variable, that signalize that something happened */
initng_global_set_interrupt();
/*
Modified: initng/plugins/daemon/initng_daemon.h
==============================================================================
--- initng/plugins/daemon/initng_daemon.h (original)
+++ initng/plugins/daemon/initng_daemon.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/daemon_clean/initng_daemon_clean.c
==============================================================================
--- initng/plugins/daemon_clean/initng_daemon_clean.c (original)
+++ initng/plugins/daemon_clean/initng_daemon_clean.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -56,7 +56,7 @@
/*
* if we return TRUE, other kill handlers wont get this signal,
- * it meens that this signal have been handled.
+ * it means that this signal have been handled.
*/
return (FALSE);
}
Modified: initng/plugins/daemon_clean/initng_daemon_clean.h
==============================================================================
--- initng/plugins/daemon_clean/initng_daemon_clean.h (original)
+++ initng/plugins/daemon_clean/initng_daemon_clean.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/empty/initng_empty.c
==============================================================================
--- initng/plugins/empty/initng_empty.c (original)
+++ initng/plugins/empty/initng_empty.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/empty/initng_empty.h
==============================================================================
--- initng/plugins/empty/initng_empty.h (original)
+++ initng/plugins/empty/initng_empty.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/envparser/initng_envparser.c
==============================================================================
--- initng/plugins/envparser/initng_envparser.c (original)
+++ initng/plugins/envparser/initng_envparser.c Wed Feb 8 08:49:31 2006
@@ -61,7 +61,7 @@
parse_file(file, s);
}
- /* Parse all, and stop if files dont exits, or not parseable */
+ /* Parse all, and stop if files don't exits, or not parseable */
while ((file =
initng_service_cache_get_next_string(&ENV_FILE_REQUIRED, s,
file)))
@@ -94,7 +94,7 @@
int i = 0;
int quoted = FALSE;
- /* skip initzial spaces */
+ /* skip initial spaces */
JUMP_SPACES(point);
if (!point[0])
break;
Modified: initng/plugins/ezxmlparser/ezxml.c
==============================================================================
--- initng/plugins/ezxmlparser/ezxml.c (original)
+++ initng/plugins/ezxmlparser/ezxml.c Wed Feb 8 08:49:31 2006
@@ -106,7 +106,7 @@
return (idx < 0) ? xml : ezxml_vget(ezxml_idx(xml, idx), ap);
}
-// Traverses the xml tree to retrive a specific subtag. Takes a variable
+// Traverses the xml tree to retrieve a specific subtag. Takes a variable
// length list of tag names and indexes. The argument list must be terminated
// by either an index of -1 or an empty string tag name. Example:
// title = ezxml_get(library, "shelf", 0, "book", 2, "title", -1);
Modified: initng/plugins/ezxmlparser/initng_ezxml_parser.c
==============================================================================
--- initng/plugins/ezxmlparser/initng_ezxml_parser.c (original)
+++ initng/plugins/ezxmlparser/initng_ezxml_parser.c Wed Feb 8 08:49:31 2006
@@ -1,5 +1,5 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 Jimmy Wennlund <jimmy.wennlund at gmail.com>
*
* This program is free software; you can redistribute it and/or
@@ -70,7 +70,7 @@
service_cache_h *got_serv = NULL;
assert(process_name);
- /* example INITNG_ROOT=/etc/initng process_name="deamon/sshd XML_EXT=".xml" */
+ /* example INITNG_ROOT=/etc/initng process_name="daemon/sshd XML_EXT=".xml" */
/* TRY NO 1, try load "/etc/initng/daemon/sshd.xml" */
/* TRY NO 2, try load "/etc/initng/daemon/sshd/sshd.xml" */
/* TRY NO 3, try load "/etc/initng/daemon/sshd/default.xml" */
@@ -290,7 +290,7 @@
return (NULL);
}
- /* check if this is the service we ar looking for */
+ /* check if this is the service we are looking for */
if (service_match(watch_for, new_service->name) == TRUE)
return (new_service);
@@ -317,7 +317,7 @@
if (current->ot && current->ot != stype)
continue;
- /* if option-name differs, continuue */
+ /* if option-name differs, continue */
if (strcmp(name, current->opt_name) != 0)
continue;
@@ -356,7 +356,7 @@
}
-/* funtion copy full string into db */
+/* function copy full string into db */
static int string_xml_parser(s_entry * type, const char *value,
service_cache_h * from_service)
{
@@ -380,7 +380,7 @@
return (FALSE);
}
-/* funtion splits up all string to single entrys */
+/* function splits up all string to single entries */
static int strings_xml_parser(s_entry * type, const char *value,
service_cache_h * from_service)
{
Modified: initng/plugins/ezxmlparser/initng_ezxml_parser.h
==============================================================================
--- initng/plugins/ezxmlparser/initng_ezxml_parser.h (original)
+++ initng/plugins/ezxmlparser/initng_ezxml_parser.h Wed Feb 8 08:49:31 2006
@@ -1,5 +1,5 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 Jimmy Wennlund <jimmy.wennlund at gmail.com>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/find/initng_find.c
==============================================================================
--- initng/plugins/find/initng_find.c (original)
+++ initng/plugins/find/initng_find.c Wed Feb 8 08:49:31 2006
@@ -88,7 +88,7 @@
assert(service);
- /* Never try to find a service with a '/' in the name, it alredy have a path */
+ /* Never try to find a service with a '/' in the name, it already have a path */
if (!strchr(service, '/'))
return NULL;
@@ -128,14 +128,14 @@
if (!open_read_close(ALIAS_FILE, &file_content))
return (NULL);
- /* get lengt of what we are searching */
+ /* get length of what we are searching */
from_len = strlen(from);
/* Start Parsing */
point = file_content;
while (point[0])
{
- /* skip initzial spaces */
+ /* skip initial spaces */
JUMP_SPACES(point);
if (!point[0])
break;
@@ -148,7 +148,7 @@
}
printf("parse row \"%s\"\n", point);
- /* chek if first word is a match */
+ /* check if first word is a match */
if (strncasecmp(point, from, from_len) != 0)
{
printf("Not the one");
Modified: initng/plugins/fstat/initng_fstat.c
==============================================================================
--- initng/plugins/fstat/initng_fstat.c (original)
+++ initng/plugins/fstat/initng_fstat.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@
"Check so that this files exits before launching."
};
s_entry FILES_TO_EXIST_AFTER = { "files_to_exist_after", STRINGS, NULL,
- "Make sure this files exits after service is lauched, or mark failed."
+ "Make sure this files exits after service is launched, or mark failed."
};
Modified: initng/plugins/fstat/initng_fstat.h
==============================================================================
--- initng/plugins/fstat/initng_fstat.h (original)
+++ initng/plugins/fstat/initng_fstat.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/history/initng_history.c
==============================================================================
--- initng/plugins/history/initng_history.c (original)
+++ initng/plugins/history/initng_history.c Wed Feb 8 08:49:31 2006
@@ -89,10 +89,10 @@
{
history_h *current, *safe = NULL;
- /* while there is a histry db */
+ /* while there is a history db */
while_history_db_safe(current, safe)
{
- /* free histry name */
+ /* free history name */
if (current->name)
free(current->name);
@@ -103,7 +103,7 @@
/* remove from history_db list */
list_del(¤t->list);
- /* free histroy entry */
+ /* free history entry */
free(current);
}
}
@@ -113,7 +113,7 @@
/* add struct */
list_add(&hist->list, &history_db.list);
- /* check lenght of history_db, and purge it on the end! */
+ /* check length of history_db, and purge it on the end! */
history_records++;
if (history_records > HISTORY)
@@ -141,7 +141,7 @@
assert(service->name);
- /* Dont bother adding */
+ /* Don't bother adding */
if (!service->current_state)
return (TRUE);
@@ -226,7 +226,7 @@
if (only_output && !current->data)
continue;
- /* if there is an argumet, it have to match the service */
+ /* if there is an argument, it have to match the service */
if (arg
&& !(((current->name) && strcmp(current->name, arg) == 0)
|| ((current->service && current->service->name)
Modified: initng/plugins/idleprobe/initng_idleprobe.c
==============================================================================
--- initng/plugins/idleprobe/initng_idleprobe.c (original)
+++ initng/plugins/idleprobe/initng_idleprobe.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -60,7 +60,7 @@
/* system have to be idle for 10 seconds */
s_entry WAIT_FOR_CPU_IDLE = { "wait_for_cpu_idle", SET, NULL,
- "If this is set, initng will wait until cpu has been idleing for 10 seconds before starting."
+ "If this is set, initng will wait until CPU has been idling for 10 seconds before starting."
};
/* set the seconds system have to be idle */
@@ -90,7 +90,7 @@
float scale;
D_("is_cpu_idle(%i);\n", wait);
- /* check so that wait valuie is correct */
+ /* check so that wait value is correct */
if (wait < 0)
{
F_("Wrong value for parameter wait_for_cpu_idle (%i)!\n", wait);
@@ -122,7 +122,7 @@
rewind(fp_proc);
fflush(fp_proc);
- // first value the cpu summary line
+ // first value the CPU summary line
if (!fgets(buf, sizeof(buf), fp_proc))
{
F_("Failed to read from /proc/stat!\n");
@@ -181,7 +181,7 @@
old_cpu_dummy2 = cpu_dummy2;
old_cpu_dummy3 = cpu_dummy3;
- /* make sure this will atleast be run in one second */
+ /* make sure this will at least be run in one second */
initng_global_set_sleep(1);
return (FALSE);
Modified: initng/plugins/idleprobe/initng_idleprobe.h
==============================================================================
--- initng/plugins/idleprobe/initng_idleprobe.h (original)
+++ initng/plugins/idleprobe/initng_idleprobe.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/inetd/initng_inetd.c
==============================================================================
--- initng/plugins/inetd/initng_inetd.c (original)
+++ initng/plugins/inetd/initng_inetd.c Wed Feb 8 08:49:31 2006
@@ -94,7 +94,7 @@
e->fdh.call_module == &accepted_client;
e->fdh.fds = socket(PF_INET, SOCK_STREAM, 0);
if (e->fdh.fds < 0) return (FALSE);
- /* allow reuse of local adresses */
+ /* allow reuse of local addresses */
if (setsockopts
(e->fdh.fsd, SOL_SOCKET, SO_REUSEADDR, &opt_val,
sizeof(opt_val)) < 0) return (FALSE);
@@ -136,7 +136,7 @@
dup2(accept_fd, 2);
close(accept_fd); initng_execute_launch(e->service, T_INET); _exit(99);}
- /* here fork, repipe and launch */
+ /* here fork, re-pipe and launch */
return;}
Modified: initng/plugins/initctl/initng_initctl.c
==============================================================================
--- initng/plugins/initctl/initng_initctl.c (original)
+++ initng/plugins/initctl/initng_initctl.c Wed Feb 8 08:49:31 2006
@@ -101,7 +101,7 @@
/* If the pipe isn't open, try to open it. */
if (pipe_fd.fds < 3)
{
- /* it the filedescriptor has to be over 2 to be valid */
+ /* it the file descriptor has to be over 2 to be valid */
if ((pipe_fd.fds = open(INIT_FIFO, O_RDWR | O_NONBLOCK)) < 3)
return (FALSE);
@@ -152,7 +152,7 @@
}
if (request.magic != INIT_MAGIC || n != sizeof(request))
{
- F_("got bogus initrequest\n");
+ F_("got bogus init request\n");
return;
}
@@ -161,12 +161,12 @@
*/
if (request.cmd != INIT_CMD_RUNLVL)
{
- D_("got unimplemented initrequest - %d (%c),%d (%c).\n",
+ D_("got unimplemented init request - %d (%c),%d (%c).\n",
request.runlevel, request.runlevel, request.cmd, request.cmd);
return;
}
- /* Todo, handle these:
+ /* TODO, handle these:
#define INIT_CMD_START 0
#define INIT_CMD_RUNLVL 1
#define INIT_CMD_POWERFAIL 2
@@ -204,7 +204,7 @@
/* reload /etc/inittab */
case 'Q':
case 'q':
- W_("init Q, freeing complite service cache\n");
+ W_("init Q, freeing complete service cache\n");
initng_service_cache_free_all();
return;
@@ -246,7 +246,7 @@
return;
}
/*
- todo, is this a good idea or a bad idea?
+ TODO, is this a good idea or a bad idea?
utmpname("/var/run/utmp");
*/
@@ -278,7 +278,7 @@
-/* try open fifo, every started service */
+/* try open FIFO, every started service */
static void hup_request(void)
{
if (!initctl_control_open())
Modified: initng/plugins/initctl/initreq.h
==============================================================================
--- initng/plugins/initctl/initreq.h (original)
+++ initng/plugins/initctl/initreq.h Wed Feb 8 08:49:31 2006
@@ -59,7 +59,7 @@
/*
* Because of legacy interfaces, "runlevel" and "sleeptime"
- * aren't in a seperate struct in the union.
+ * aren't in a separate struct in the union.
*
* The weird sizes are because init expects the whole
* struct to be 384 bytes.
Modified: initng/plugins/interactive/initng_interactive.c
==============================================================================
--- initng/plugins/interactive/initng_interactive.c (original)
+++ initng/plugins/interactive/initng_interactive.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@
static int interactive_STARTING(active_db_h * service);
static int interactive_STOP_MARKED(active_db_h * service);
-a_state_h INT_DISABLED = { "INTERACTIVLY_DISABLED", IS_FAILED, NULL };
+a_state_h INT_DISABLED = { "INTERACTIVELY_DISABLED", IS_FAILED, NULL };
static int interactive_STARTING(active_db_h * service)
{
Modified: initng/plugins/interactive/initng_interactive.h
==============================================================================
--- initng/plugins/interactive/initng_interactive.h (original)
+++ initng/plugins/interactive/initng_interactive.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/iparser/initng_i_parser.c
==============================================================================
--- initng/plugins/justbeforeX/initng_jbx.c (original)
+++ initng/plugins/justbeforeX/initng_jbx.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* A plugin to launch services just before X starts.
* The start of X is delayed until all jbX services are started.
* Copyright (C) 2005 Thomas 'SaTaN0rX' Ilnseher <illth at gmx.de>
@@ -141,7 +141,7 @@
{
if (strstr(X_services[i].reqd_services, service->name))
{
- printf("The current service \"%s\" is requrement to \"%s\"\n",
+ printf("The current service \"%s\" is requirement to \"%s\"\n",
service->name, X_services[i].serv->name);
is_X = TRUE;
Modified: initng/plugins/justbeforeX/initng_jbx.h
==============================================================================
--- initng/plugins/justbeforeX/initng_jbx.h (original)
+++ initng/plugins/justbeforeX/initng_jbx.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/last/initng_last.c
==============================================================================
--- initng/plugins/last/initng_last.c (original)
+++ initng/plugins/last/initng_last.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -58,7 +58,7 @@
D_("LAST: walking through service db\n");
while_active_db(current)
{
- /* dont check ourself */
+ /* don't check ourself */
if (current == service)
continue;
@@ -75,7 +75,7 @@
/* if current need service that should be last */
if (initng_depend_deep(current, service) == TRUE)
{
- /* dont wait, becouse this wait is circular */
+ /* don't wait, because this wait is circular */
D_("Service %s depends on %s\n", service->name, current->name);
continue;
}
@@ -88,7 +88,7 @@
}
}
- /* ok, filaly last start this */
+ /* ok, finally last start this */
return (TRUE);
}
Modified: initng/plugins/last/initng_last.h
==============================================================================
--- initng/plugins/last/initng_last.h (original)
+++ initng/plugins/last/initng_last.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/limit/initng_limit.c
==============================================================================
--- initng/plugins/limit/initng_limit.c (original)
+++ initng/plugins/limit/initng_limit.c Wed Feb 8 08:49:31 2006
@@ -104,13 +104,13 @@
"The maximum size of the process stack, soft limit."
};
-/* fetch the corrent error string */
+/* fetch the correct error string */
static const char *err_desc(void)
{
switch (errno)
{
case EFAULT:
- return ("Rlim prints outside the accessible adress space.\n");
+ return ("Rlim prints outside the accessible address space.\n");
case EINVAL:
return ("Resource is not valid.\n");
case EPERM:
@@ -164,7 +164,7 @@
D_("now: soft: %i, hard: %i\n", l.rlim_cur, l.rlim_max);
- /* set the limit and resturn status */
+ /* set the limit and return status */
if (setrlimit(ltype, &l) != 0)
{
F_("setrlimit failed, service: %s, limit type %i: %s\n",
Modified: initng/plugins/netprobe/initng_netprobe.c
==============================================================================
--- initng/plugins/netprobe/initng_netprobe.c (original)
+++ initng/plugins/netprobe/initng_netprobe.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -106,7 +106,7 @@
}
s_entry REQUIRE_NETWORK = { "require_network", SET, NULL,
- "If set, initng will wait for an active internet connection before starting this service."
+ "If set, initng will wait for an active Internet connection before starting this service."
};
s_entry NETWORK_PROVIDER = { "network_provider", SET, NULL,
"Set this on services that provides network, and if will be stopped after daemons have quit."
@@ -141,7 +141,7 @@
return (TRUE);
/*
- * I belive that we are way better probing this in kernel,
+ * I believe that we are way better probing this in kernel,
* then waiting for the net provider service to be up.
*/
#ifdef REQUIRE_NETWORK_PROVIDER_SERVICE_TO_BE_UP
@@ -152,7 +152,7 @@
if (initng_active_db_is(&NETWORK_PROVIDER, current) && IS_UP(current))
goto ok;
}
- /* Dont set sleep 1, becouse initng will be interrupted when a
+ /* Don't set sleep 1, because initng will be interrupted when a
* service changes state anyway.
*/
/*initng_set_sleep(1); */
@@ -163,7 +163,7 @@
/*
* Now when we now that there is a network provider that
- * is really up, wo do an check with kernel network subsytem
+ * is really up, we do an check with kernel network subsystem
* so we now this is true.
*/
@@ -177,7 +177,7 @@
if (network_status == TRUE)
return (TRUE);
- /* Make sure mainlop will run within 1 second. */
+ /* Make sure mainloop will run within 1 second. */
initng_global_set_sleep(1);
return (FALSE);
Modified: initng/plugins/netprobe/initng_netprobe.h
==============================================================================
--- initng/plugins/netprobe/initng_netprobe.h (original)
+++ initng/plugins/netprobe/initng_netprobe.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/ngc2/initng_ngc2.c
==============================================================================
--- initng/plugins/ngc2/initng_ngc2.c (original)
+++ initng/plugins/ngc2/initng_ngc2.c Wed Feb 8 08:49:31 2006
@@ -72,7 +72,7 @@
static void cmd_stop(char *arg, FILE * fd);
/*
- In the Linux implementation, sockets which are visible in the filesystem
+ In the Linux implementation, sockets which are visible in the file system
honour the permissions of the directory they are in. Their owner, group
and their permissions can be changed. Creation of a new socket will
fail if the process does not have write and search (execute) permission
@@ -134,7 +134,7 @@
memset(&result, 0, sizeof result);
result.p_ver = PROTOCOL_VERSION;
- s_command *tmp_cmd; /* temprary storage for a command */
+ s_command *tmp_cmd; /* temporary storage for a command */
assert(file_sock);
@@ -386,7 +386,7 @@
return;
}
- /* temporary unavaible */
+ /* temporary unavailable */
if ((errno == EAGAIN) || (errno == EWOULDBLOCK))
{
W_("errno = EAGAIN!\n");
@@ -399,7 +399,7 @@
return;
}
-/* Send a ping to ourselfes to check if we're 100% ok. */
+/* Send a ping to ourselves to check if we're 100% ok. */
static int sendping()
{
int client;
@@ -435,7 +435,7 @@
return FALSE;
}
- /* Write X to ping ourselfes */
+ /* Write X to ping ourselves */
header.c = 'X';
header.l[0] = '\0';
@@ -459,7 +459,7 @@
(signed) sizeof(result_desc)) || result.c != 'Y'
|| result.s != S_TRUE)
{
- F_("Unable to rescive PONG!\n");
+ F_("Unable to receive PONG!\n");
close(client);
return (FALSE);
}
@@ -485,7 +485,7 @@
{
if (errno != EROFS)
F_("Could not create " SOCKET_ROOTPATH
- " : %s, maby / fs not mounted read-write yet?, will retry until I succeed.\n",
+ " : %s, may be / fs not mounted read-write yet?, will retry until I succeed.\n",
strerror(errno));
return (FALSE);
}
@@ -574,7 +574,7 @@
/* Run check : */
if (!sendping())
{
- F_("Sendping check failed, ngc2 comunication not available (if you see this open a bug)\n");
+ F_("Sendping check failed, ngc2 communication not available (if you see this open a bug)\n");
closesock();
return (FALSE);
}
@@ -712,7 +712,7 @@
strncpy(row.n, serv->name, 100);
if (IS_UP(serv))
{
- strcpy(row.s, "ALREDY_RUNNING");
+ strcpy(row.s, "ALREADY_RUNNING");
}
else
{
Modified: initng/plugins/ngc2/initng_ngc2.h
==============================================================================
--- initng/plugins/ngc2/initng_ngc2.h (original)
+++ initng/plugins/ngc2/initng_ngc2.h Wed Feb 8 08:49:31 2006
@@ -69,7 +69,7 @@
typedef struct
{
- e_suceed s; /* suceeed, TRUE or FALSE */
+ e_suceed s; /* succeed, TRUE or FALSE */
char c;
int t; /* type of data got back */
char version[101];
Modified: initng/plugins/ngc2/ngc2.c
==============================================================================
--- initng/plugins/ngc2/ngc2.c (original)
+++ initng/plugins/ngc2/ngc2.c Wed Feb 8 08:49:31 2006
@@ -45,7 +45,7 @@
#include "initng_ngc2.h"
-/* maximum size of string rescived, warning ngc -p can contain a lot */
+/* maximum size of string received, warning ngc -p can contain a lot */
#define MAX_RESCIVE_SIZE 100000
#define TRUE 1
@@ -61,7 +61,7 @@
#define TMP_QUIET if(quiet==FALSE) quiet=3;
#define TMP_UNQUIET if(quiet==3) quiet=FALSE;
-/* Global comunication socket */
+/* Global communication socket */
static int sock = -1;
/* functions */
@@ -190,7 +190,7 @@
/* no idea to stress initng */
usleep(50000);
- /* if we are reloading initng, we wont have an answ from it, so don't fetch any */
+ /* if we are reloading initng, we wont have an answer from it, so don't fetch any */
if (header.c == 'c')
{
print_out
@@ -214,7 +214,7 @@
/* check that protocol matches */
if (result->p_ver != PROTOCOL_VERSION)
{
- print_out("PROTOCOL_VERSION missmatch :\n");
+ print_out("PROTOCOL_VERSION mismatch :\n");
print_out
(" initng_protocol_version: %i, client_protocol_version: %i !\n",
result->p_ver, PROTOCOL_VERSION);
@@ -359,13 +359,13 @@
if (row.i == IS_UP)
{
- if (strcmp(row.s, "ALREDY_RUNNING") == 0)
+ if (strcmp(row.s, "ALREADY_RUNNING") == 0)
{
- print_out("\tService \"%s\" alredy running!\n", row.n);
+ print_out("\tService \"%s\" already running!\n", row.n);
}
else
{
- print_out("\tService \"%s\" started sucessfully! (%s)\n", row.n,
+ print_out("\tService \"%s\" started successfully! (%s)\n", row.n,
row.s);
}
return (TRUE);
@@ -393,7 +393,7 @@
if (strcmp(row.s, "NOT_FOUND") == 0)
{
- print_out("This meens that the service cound not start,\n");
+ print_out("This means that the service could not start,\n");
print_out("Please check initng console, syslogs or ngc -L\n");
print_out("For more info.\n\n");
@@ -405,7 +405,7 @@
print_out
("Will not make an attempt to reset service state and try again\n");
- TMP_QUIET; /* dont print zap result */
+ TMP_QUIET; /* don't print zap result */
/* zap the service */
if (!send_and_handle('z', NULL, row.n))
return (FALSE);
@@ -480,11 +480,11 @@
return FALSE;
}
- /* not found can be goood */
+ /* not found can be good */
if (once_found == 1 && strcmp(row.s, "NOT_FOUND") == 0)
break;
- /* If its NOT_FOUND in future, then its a goot thing */
+ /* If its NOT_FOUND in future, then its a Godot thing */
once_found = 1;
/* break if failed */
@@ -497,10 +497,10 @@
}
close_socket();
- /* not found can be goood */
+ /* not found can be Good */
if (once_found == 1 && strcmp(row.s, "NOT_FOUND") == 0)
{
- print_out("\tService \"%s\" stopped sucessfully!\n", row.n);
+ print_out("\tService \"%s\" stopped successfully!\n", row.n);
return (TRUE);
}
@@ -521,7 +521,7 @@
print_out("Service \"%s\" has status failed to stop.\n", row.n);
- print_out("Instead you shud kill this service manually,\n");
+ print_out("Instead you should kill this service manually,\n");
print_out("And after that do ngc -z %s, to release\n", row.s);
print_out("its status from initng.\n\n");
return (FALSE);
@@ -530,11 +530,11 @@
static int handle_result(result_desc * result)
{
- /* special handleing commands */
+ /* special handling commands */
switch (result->c)
{
case 'h': /* standard option list */
- case 'H': /* advanched option list */
+ case 'H': /* advanced option list */
return (ngc_hlp());
case 's':
return (ngc_active_db());
@@ -584,7 +584,7 @@
case COMMAND_FAIL:
default:
close_socket();
- print_out("unkown data!, no haldler!\n");
+ print_out("unknown data!, no handler!\n");
bad_syntax();
exit(1);
Modified: initng/plugins/ngcs/initng_ngcs.c
==============================================================================
--- initng/plugins/ngcs/initng_ngcs.c (original)
+++ initng/plugins/ngcs/initng_ngcs.c Wed Feb 8 08:49:31 2006
@@ -74,7 +74,7 @@
void clean_dead_conns(void);
/*
- In the Linux implementation, sockets which are visible in the filesystem
+ In the Linux implementation, sockets which are visible in the file system
honour the permissions of the directory they are in. Their owner, group
and their permissions can be changed. Creation of a new socket will
fail if the process does not have write and search (execute) permission
@@ -162,7 +162,7 @@
return;
}
- /* temporary unavaible */
+ /* temporary unavailable */
if ((errno == EAGAIN) || (errno == EWOULDBLOCK))
{
W_("errno = EAGAIN!\n");
@@ -360,7 +360,7 @@
}
#if 0
-/* Send a ping to ourselfes to check if we're 100% ok. */
+/* Send a ping to ourselves to check if we're 100% ok. */
static int sendping()
{
int client;
@@ -435,7 +435,7 @@
{
if (errno != EROFS)
F_("Could not create " SOCKET_ROOTPATH
- " : %s, maby / fs not mounted read-write yet?, will retry until I succeed.\n",
+ " : %s, may be / fs not mounted read-write yet?, will retry until I succeed.\n",
strerror(errno));
return (FALSE);
}
@@ -505,7 +505,7 @@
/* Run check : */
/* if (!sendping())
{
- F_("Sendping check failed, ngcs comunication not available (if you see this open a bug)\n");
+ F_("Sendping check failed, ngcs communication not available (if you see this open a bug)\n");
closesock();
return (FALSE);
} */
Modified: initng/plugins/pause/initng_pause.c
==============================================================================
--- initng/plugins/pause/initng_pause.c (original)
+++ initng/plugins/pause/initng_pause.c Wed Feb 8 08:49:31 2006
@@ -63,7 +63,7 @@
if (ms_delay)
{
- D_("Sleeping for %i miliseconds.\n", ms_delay);
+ D_("Sleeping for %i milliseconds.\n", ms_delay);
usleep(ms_delay);
}
Modified: initng/plugins/pidfile/initng_pidfile.c
==============================================================================
--- initng/plugins/pidfile/initng_pidfile.c (original)
+++ initng/plugins/pidfile/initng_pidfile.c Wed Feb 8 08:49:31 2006
@@ -110,7 +110,7 @@
struct dirent *d;
FILE *fp;
- /* maximum possible lengh for string "/proc/12232/stat" can be */
+ /* maximum possible length for string "/proc/12232/stat" can be */
#define BUFF_SIZE 512
D_("Will fetch pid of \"%s\"\n", name);
@@ -124,8 +124,8 @@
{
char buf[BUFF_SIZE + 1]; /* Will contain a fixed string like "/proc/12232/stat" */
char *s = NULL; /* Temporary pointer when parsing the content of the stat file */
- int len = 0; /* An lenght counter */
- pid_t pid = -1; /* Will cotnain the pid to return */
+ int len = 0; /* An length counter */
+ pid_t pid = -1; /* Will contain the pid to return */
/* Make sure this dirname is a number == pid */
if ((pid = atoi(d->d_name)) <= 0)
@@ -152,7 +152,7 @@
/* close stat file */
fclose(fp);
- /* set the walk conter, to the start of the file countet fetched */
+ /* set the walk counter, to the start of the file content fetched */
s = buf;
/* skip all chars to the first space - first string contains the pid no */
@@ -166,12 +166,12 @@
/* skip the space */
s++;
- /* skipp the '(' char */
+ /* skip the '(' char */
if (*s != '(')
continue;
s++;
- /* count the lenght */
+ /* count the length */
while (s[len] && s[len] != ')')
len++;
@@ -358,7 +358,7 @@
D_("will handle %s status %s\n", s->name, s->current_state->state_name);
- /* if rcode indicate failure, dont check for pidfile */
+ /* if rcode indicate failure, don't check for pidfile */
if (p->r_code > 0)
{
W_("Daemon for service %s returned with an bad return code %i, wont look for a pidfile.\n", s->name, p->r_code);
@@ -469,7 +469,7 @@
if (kill(pid, 0) < 0 && (errno == ESRCH))
{
- F_("Got a non-existant pid %i for daemon \"%s\"\n", pid, s->name);
+ F_("Got a non-existent pid %i for daemon \"%s\"\n", pid, s->name);
initng_common_mark_service(s, &FAIL_STARTING);
return;
}
Modified: initng/plugins/provide/initng_provide.c
==============================================================================
--- initng/plugins/provide/initng_provide.c (original)
+++ initng/plugins/provide/initng_provide.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/provide/initng_provide.h
==============================================================================
--- initng/plugins/provide/initng_provide.h (original)
+++ initng/plugins/provide/initng_provide.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/reload/initng_reload.c
==============================================================================
--- initng/plugins/reload/initng_reload.c (original)
+++ initng/plugins/reload/initng_reload.c Wed Feb 8 08:49:31 2006
@@ -1,5 +1,5 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -98,7 +98,7 @@
/* set service stype */
if (!(new_entry->type = initng_service_types_get(entry.type)))
{
- F_("Unkown service type %s.\n", entry.type);
+ F_("Unknown service type %s.\n", entry.type);
success = FALSE; continue;
}
@@ -106,7 +106,7 @@
memcpy(&new_entry->time_current_state, &entry.time_current_state,
sizeof(struct timeval));
- /* walk thru all processes */
+ /* walk through all processes */
{
int pnr = 0;
@@ -192,7 +192,7 @@
success = FALSE; continue;
}
- /* Dont need to reload data from disk, loaded when needed
+ /* Don't need to reload data from disk, loaded when needed
if (get_service(new_entry) == TRUE)
new_entry->from_service =
service_db_find_by_name(new_entry->name);
@@ -248,7 +248,7 @@
memcpy(&entry.time_current_state, ¤t->time_current_state,
sizeof(struct timeval));
- /* collet some proceses */
+ /* collect some processes */
process = NULL;
pnr = 0;
while_processes(process, current)
@@ -305,7 +305,7 @@
/* save in next data entry row */
i++;
- /* maximum data entrys that can be saved */
+ /* maximum data entries that can be saved */
if (i == MAX_ENTRYS_FOR_SERVICE)
{
F_("Maximum 20 data entries / service can't be saved!\n");
Modified: initng/plugins/reload/initng_reload.h
==============================================================================
--- initng/plugins/reload/initng_reload.h (original)
+++ initng/plugins/reload/initng_reload.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/respawn/initng_respawn.c
==============================================================================
--- initng/plugins/respawn/initng_respawn.c (original)
+++ initng/plugins/respawn/initng_respawn.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -50,7 +50,7 @@
s_entry RESPAWN = { "respawn", SET, &TYPE_DAEMON,
- "If this is set and dameon dies, it will be restarted."
+ "If this is set and daemon dies, it will be restarted."
};
a_state_h WAIT_RESP_TOUT = { "WAIT_FOR_RESPAWN_TIMEOUT", IS_DOWN, &resp_try };
@@ -69,12 +69,12 @@
D_("Calling check_respawn for service %s state %s -> %s\n", service->name,
service->current_state->state_name, status->state_name);
- /* look for when initng are trying to set a servuce to STOPPED */
+ /* look for when initng are trying to set a service to STOPPED */
/* if (status != &STOPPED || status != &DAEMON_EXIT_BAD)
return (TRUE); */
if(status->is != IS_DOWN) return (TRUE);
- /* check that current status is RUNNING, so it realy died, and not is manually stopped */
+ /* check that current status is RUNNING, so it really died, and not is manually stopped */
if (!IS_MARK(service, &RUNNING))
{
D_("service %s is going to be marked STOPPED,\nbut not from status RUNNING, \nit's from %s\n\n", service->name, service->current_state->state_name);
@@ -100,7 +100,7 @@
last = (time_t) initng_active_db_get_int(&LAST_RESPAWN, service);
D_("Now: %i , Last: %i\n", g.now.tv_sec, last);
- /* make sure it wont respawn to ofthen */
+ /* make sure it wont respawn to often */
if (last)
{
if (g.now.tv_sec - last < MAX_RESPAWN_RATE)
@@ -135,13 +135,13 @@
return;
}
- /* If set to loading, it will automaticly be started. */
+ /* If set to loading, it will automatically be started. */
initng_common_mark_service(service, &LOADING);
/* to make sure it will be started */
initng_handler_start_service(service);
- /* don't allow change top STOPPED, it is set to STARTING with start_service abow */
+ /* don't allow change top STOPPED, it is set to STARTING with start_service above */
return;
}
Modified: initng/plugins/respawn/initng_respawn.h
==============================================================================
--- initng/plugins/respawn/initng_respawn.h (original)
+++ initng/plugins/respawn/initng_respawn.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/rlparser/initng_rl_parser.c
==============================================================================
--- initng/plugins/rlparser/initng_rl_parser.c (original)
+++ initng/plugins/rlparser/initng_rl_parser.c Wed Feb 8 08:49:31 2006
@@ -76,7 +76,7 @@
if (n_service->name)
free(n_service->name);
- /* free all data entrys */
+ /* free all data entries */
initng_service_cache_remove_all(n_service);
if (n_service)
Modified: initng/plugins/service/initng_service.c
==============================================================================
--- initng/plugins/service/initng_service.c (original)
+++ initng/plugins/service/initng_service.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -99,17 +99,17 @@
a_state_h SERVICE_START_MARKED = { "SERVICE_START_MARKED", IS_STARTING, &handle_SERVICE_START_MARKED };
/*
- * When we want to stop a SERVICE_DONE service, its marked SERVIE_STOP_MARKED
+ * When we want to stop a SERVICE_DONE service, its marked SERVICE_STOP_MARKED
*/
a_state_h SERVICE_STOP_MARKED = { "SERVICE_STOP_MARKED", IS_STOPPING, &handle_SERVICE_STOP_MARKED };
/*
- * When a service is UP, it is marked as SERVIVE_DONE
+ * When a service is UP, it is marked as SERVICE_DONE
*/
a_state_h SERVICE_DONE = { "SERVICE_DONE", IS_UP, NULL };
/*
- * When services needed by current one is starting, current service is set SERVICE_WAITNING_FOR_START_DEP
+ * When services needed by current one is starting, current service is set SERVICE_WAITING_FOR_START_DEP
*/
a_state_h SERVICE_WAITING_FOR_START_DEP = { "SERVICE_WAITING_FOR_START_DEP", IS_STARTING,
&handle_SERVICE_WAITING_FOR_START_DEP };
@@ -131,7 +131,7 @@
a_state_h SERVICE_STOP_DEPS_MET = { "SERVICE_STOP_DEPS_MET", IS_STARTING, &handle_SERVICE_STOP_DEPS_MET };
/*
- * This markes the services, as DOWN.
+ * This marks the services, as DOWN.
*/
a_state_h SERVICE_STOPPED = { "SERVICE_STOPPED", IS_DOWN, NULL };
@@ -164,7 +164,7 @@
/* This are run, when initng wants to start a service */
static int start_SERVICE(active_db_h * service_to_start)
{
- /* Start our dependencys */
+ /* Start our dependencies */
if(initng_depend_start_deps(service_to_start)!=TRUE)
return(FALSE);
@@ -179,7 +179,7 @@
}
-/* This are run, when initng wats to stop a service */
+/* This are run, when initng wants to stop a service */
static int stop_SERVICE(active_db_h * service)
{
/* set stopping */
@@ -191,7 +191,7 @@
/*
* ############################################################################
- * # PLUGIN INITSIATORS #
+ * # PLUGIN INITIATORS #
* ############################################################################
*/
@@ -297,7 +297,7 @@
if (initng_depend(service, current) == FALSE)
continue;
- /* if servuce dep on is starting, wait a bit */
+ /* if service dep on is starting, wait a bit */
if (IS_STARTING(current))
return;
@@ -312,11 +312,11 @@
}
}
- /* this checks with external plugins, if its ok to start this service now */
+ /* this checks with external plug-ins, if its ok to start this service now */
if(initng_depend_start_dep_met(service)!=TRUE)
return;
- /* if system is shuting down, dont start anything */
+ /* if system is shutting down, don't start anything */
if (g.sys_state != STATE_STARTING && g.sys_state != STATE_UP)
{
D_("Can't start service, when system status is: %i !\n", g.sys_state);
@@ -348,7 +348,7 @@
if (initng_depend(current, service) == FALSE)
continue;
- /* if its done, this is pefrect */
+ /* if its done, this is perfect */
if (IS_DOWN(current))
continue;
@@ -369,7 +369,7 @@
return;
}
- /* check with other plugins, if it is ok to stop this service now */
+ /* check with other plug-ins, if it is ok to stop this service now */
if(initng_depend_stop_dep_met(service)!=TRUE)
return;
@@ -451,7 +451,7 @@
if (current == service_stopped)
continue;
- /* DONT stop runlevels OR virtuals */
+ /* DON'T stop runlevels OR virtuals */
if (current->type == &TYPE_VIRTUAL)
continue;
@@ -459,7 +459,7 @@
if (initng_depend(current, service_stopped) == FALSE)
continue;
- /* dont stop a stopped service */
+ /* don't stop a stopped service */
if (IS_DOWN(current))
continue;
@@ -488,7 +488,7 @@
/*
* ############################################################################
- * # KILLHANDLER FUNCTIONS #
+ * # KILL HANDLER FUNCTIONS #
* ############################################################################
*/
@@ -511,7 +511,7 @@
D_("handle_killed_start(%s): initial status: \"%s\".\n",
service->name, service->current_state->state_name);
- /* Set the universal variable, that signalize that something happend */
+ /* Set the universal variable, that signalize that something happened */
initng_global_set_interrupt();
/*
Modified: initng/plugins/service/initng_service.h
==============================================================================
--- initng/plugins/service/initng_service.h (original)
+++ initng/plugins/service/initng_service.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/simple_launcher/initng_simple_launcher.c
==============================================================================
--- initng/plugins/simple_launcher/initng_simple_launcher.c (original)
+++ initng/plugins/simple_launcher/initng_simple_launcher.c Wed Feb 8 08:49:31 2006
@@ -53,7 +53,7 @@
s_entry EXEC =
{ "exec", VARIABLE_STRING, NULL,
-"Contains the path and argumetns to a file to exec." };
+"Contains the path and arguments to a file to exec." };
s_entry EXECS = { "exec_path", VARIABLE_STRINGS, NULL,
"The path for one ore more executables."
@@ -82,7 +82,7 @@
* Contains old Code from SaTaN0rX and DEac-.
* @author TheLich
* @param exec filename, which searched.
- * @return executeable file with absolute path.\nIf exec was absolute, this will be a pointer to exec.
+ * @return executable file with absolute path.\nIf exec was absolute, this will be a pointer to exec.
* On failure, it will return NULL.
*/
@@ -103,11 +103,11 @@
* only search the PATH if this is NOT already an absolute path
*/
- /* if path provided, youst return */
+ /* if path provided, just return */
if (exec[0] == '/')
return (NULL);
- /* fet exec string lenght to later use */
+ /* get exec string length to later use */
exec_len = strlen(exec);
D_("initng_s_launch: %s is not an absolute path, searching $PATH\n",
@@ -135,10 +135,10 @@
/* split path by ':' char */
path_argv = split_delim(PATH, ":", &path_c, 0);
- /* walk the list of entrys */
+ /* walk the list of entries */
for (i = 0; path_argv[i]; i++)
{
- /* get entry lenght */
+ /* get entry length */
len = strlen(path_argv[i]);
/* what does this do? */
@@ -209,7 +209,7 @@
process_to_exec->pid = 0;
return FALSE;
- /* if to test want to lock this up util fork is done ... waitpid(pid_fork,0,0); */
+ /* if to test want to lock this up until fork is done ... waitpid(pid_fork,0,0); */
} /* end fork_and_exec() */
@@ -240,10 +240,10 @@
return (FALSE);
}
- /* split the string, with entrys to an array of strings */
+ /* split the string, with entries to an array of strings */
argv = split_delim(exec_args, WHITESPACE, &argc, 1);
- /* make sure it succeded */
+ /* make sure it succeeded */
if (!argv || !argv[0])
{
F_("split_delim exec_args returns NULL.\n");
@@ -305,7 +305,7 @@
free(exec_fixed);
exec_fixed = NULL;
- /* Return true if sucessfull */
+ /* Return true if successfully */
if (res == TRUE)
return (TRUE);
Modified: initng/plugins/splash/initng_splash.c
==============================================================================
--- initng/plugins/splash/initng_splash.c (original)
+++ initng/plugins/splash/initng_splash.c Wed Feb 8 08:49:31 2006
@@ -272,8 +272,8 @@
{
fprintf(fd, "progress 99\n");
fprintf(fd, "allowchvt\n"); //do we need this?
- fprintf(fd, "exit\n"); //terminate splasy
- //Now we should switch to the terminal X start on -but how canwe find out
+ fprintf(fd, "exit\n"); //terminate splashy
+ //Now we should switch to the terminal X start on -but how can we find out
//which terminal it is?
}
else
Modified: initng/plugins/stcmd/initng_stcmd.c
==============================================================================
--- initng/plugins/stcmd/initng_stcmd.c (original)
+++ initng/plugins/stcmd/initng_stcmd.c Wed Feb 8 08:49:31 2006
@@ -233,7 +233,7 @@
if (!(apt = initng_active_db_find_in_name(arg)))
return (-1);
- /* browse all proceses */
+ /* browse all processes */
while_processes(process, apt)
{
/* return the first process found */
@@ -335,7 +335,7 @@
if (!arg)
{
- fprintf(fd, "Please tell me what service to get uptime from.\n");
+ fprintf(fd, "Please tell me what service to get up-time from.\n");
return;
}
@@ -347,7 +347,7 @@
}
gettimeofday(&now, NULL);
- fprintf(fd, "Uptime is %ims.\n", MS_DIFF(now, apt->time_current_state));
+ fprintf(fd, "Up-time is %ims.\n", MS_DIFF(now, apt->time_current_state));
return;
}
@@ -428,7 +428,7 @@
if (initng_load_module(arg) == NULL)
return (FALSE);
- /* clear the service chache, so new variables will be read next time */
+ /* clear the service cache, so new variables will be read next time */
initng_service_cache_free_all();
return (TRUE);
@@ -439,7 +439,7 @@
if (!arg)
return (FALSE);
- /* Youst to make sure. */
+ /* Just to make sure. */
initng_service_cache_free_all();
return (initng_unload_module_named(arg));
@@ -705,7 +705,7 @@
break;
default:
g.verbose = 0;
- W_("Unknow verbose id %i\n", g.verbose);
+ W_("Unknown verbose id %i\n", g.verbose);
break;
}
return (g.verbose);
Modified: initng/plugins/stcmd/print_service.c
==============================================================================
--- initng/plugins/stcmd/print_service.c (original)
+++ initng/plugins/stcmd/print_service.c Wed Feb 8 08:49:31 2006
@@ -79,7 +79,7 @@
assert(s);
assert(s->name);
- /* try calculate out how mutch memory we wanna allocate
+ /* try calculate out how much memory we wanna allocate
that we will send */
if (intro)
@@ -219,7 +219,7 @@
assert(s);
assert(s->name);
- /* try calculate out how mutch memory we wanna allocate
+ /* try calculate out how much memory we wanna allocate
that we will send */
if (intro)
Modified: initng/plugins/stdout/initng_stdout.c
==============================================================================
--- initng/plugins/stdout/initng_stdout.c (original)
+++ initng/plugins/stdout/initng_stdout.c Wed Feb 8 08:49:31 2006
@@ -60,7 +60,7 @@
const char *s_stdall = NULL;
const char *s_stdin = NULL;
- /* filedescriptors */
+ /* file descriptors */
int fd_stdout = -1;
int fd_stderr = -1;
int fd_stdall = -1;
@@ -102,7 +102,7 @@
}
else
{
- /* else set them to diffrent files */
+ /* else set them to different files */
if (s_stdout)
fd_stdout = open(s_stdout,
O_WRONLY | O_NOCTTY | O_CREAT | O_APPEND, 0644);
@@ -134,7 +134,7 @@
D_("StdIN: %s, fd %i\n", s_stdin, fd_stdin);
#endif
- /* if fd succeded to open */
+ /* if fd succeeded to open */
if (fd_stdall > 2)
{
/* dup both to stdall */
Modified: initng/plugins/syncron/initng_syncron.c
==============================================================================
--- initng/plugins/syncron/initng_syncron.h (original)
+++ initng/plugins/syncron/initng_syncron.h Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
Modified: initng/plugins/syslog/initng_syslog.c
==============================================================================
--- initng/plugins/syslog/initng_syslog.c (original)
+++ initng/plugins/syslog/initng_syslog.c Wed Feb 8 08:49:31 2006
@@ -55,7 +55,7 @@
{
syslog_running = 1;
- /* print out the buffert if any now */
+ /* print out the buffers if any now */
if (!list_empty(&log_list.list))
{
log_ent *current, *safe = NULL;
@@ -82,7 +82,7 @@
{
log_ent *current, *safe = NULL;
- /* give syslog a last chanche to come alive */
+ /* give syslog a last chance to come alive */
check_syslog();
while_log_list_safe(current, safe)
{
@@ -308,13 +308,13 @@
return (FALSE);
}
- /* Dont clutter syslog in fake mode */
+ /* Don't clutter syslog in fake mode */
if (getpid() != 1 || !g.i_am_init)
{
W_("Pid is not 1, (%i), or g.i_am_init not set and the syslog plugin won't load when running in fake mode, to prevent cluttering up the log-files.\n", getpid());
return (TRUE);
}
- D_("Initziating syslog plugin\n");
+ D_("Initializing syslog plugin\n");
INIT_LIST_HEAD(&log_list.list);
check_syslog();
@@ -333,7 +333,7 @@
void module_unload(void)
{
- /* Dont clutter syslog in fake mode */
+ /* Don't clutter syslog in fake mode */
if (!g.i_am_init)
{
D_("The syslog plugin won't load when running in fake mode, to prevent cluttering up the log-files.\n");
Modified: initng/plugins/unneeded/initng_unneeded.c
==============================================================================
--- initng/plugins/unneeded/initng_unneeded.c (original)
+++ initng/plugins/unneeded/initng_unneeded.c Wed Feb 8 08:49:31 2006
@@ -69,10 +69,10 @@
S_;
- /* walk thru all and check */
+ /* walk through all and check */
while_active_db_safe(A, As)
{
- /* don't stop virtals */
+ /* don't stop virtuals */
if (A->type == &TYPE_VIRTUAL)
continue;
if (A->type == &TYPE_RUNLEVEL)
@@ -84,7 +84,7 @@
while_active_db(B)
{
- /* dont check ourself */
+ /* don't check ourself */
if (A == B)
continue;
Modified: initng/plugins/usplash/initng_usplash.c
==============================================================================
--- initng/plugins/usplash/initng_usplash.c (original)
+++ initng/plugins/usplash/initng_usplash.c Wed Feb 8 08:49:31 2006
@@ -52,19 +52,19 @@
#include "initng_usplash.h"
/*
- todo :
+ TODO :
update key initscripts such as fsck with output of whats going on
only update progress if it's been more than a 10% change?
- need to clean tty's and kill usplash when system has booted. (see /etc/init.d/usplash on ubuntu systems)
- cache usplash's fifo, we're run after initial so nothing is screwing with /dev at this point.
+ need to clean ttys and kill usplash when system has booted. (see /etc/init.d/usplash on ubuntu systems)
+ cache usplash's FIFO, we're run after initial so nothing is screwing with /dev at this point.
*/
-// Buffer is used for snprintf before writing to usplash fifo.
+// Buffer is used for snprintf before writing to usplash FIFO.
static char printf_buffer[1024];
static void usplash_write(char *output)
{
- int len = strlen(output) + 1; // catch \0 aswell
+ int len = strlen(output) + 1; // catch \0 as well
int fd = open(USPLASH_FIFO, O_WRONLY | O_NONBLOCK);
if (fd > 0)
@@ -91,7 +91,7 @@
USPLASH_WRITE("PROGRESS %d", percent);
last_percent = percent;
}
- // Theese seem to take quite a bit of resources for me, and actually slow down boot.
+ // These seem to take quite a bit of resources for me, and actually slow down boot.
// 18 seconds boot without these, 26 with.
/* if (IS_MARK(service,&DONE))
USPLASH_WRITE("TEXT %s : DONE",service->name)
More information about the Initng-svn
mailing list
--- initng/plugins/iparser/initng_i_parser.c (original)
+++ initng/plugins/iparser/initng_i_parser.c Wed Feb 8 08:49:31 2006
@@ -45,7 +45,7 @@
#define ENDED(x) (!(x)[0] || (x)[0]=='\n')
char *g_filename = NULL;
-char *g_pointer = NULL; /* a pointer to the first char we can backstep to when printing line copys */
+char *g_pointer = NULL; /* a pointer to the first char we can back step to when printing line copies */
/* set this to have a really verbose walking output */
@@ -120,7 +120,7 @@
/* put spaces */
memset(pstr, ' ', sizeof(char) * (pi));
- /* Tabs destroy our posistion pointers, replaces with spaces */
+ /* Tabs destroy our position pointers, replaces with spaces */
for (i = 0; line[i]; i++)
if (line[i] == '\t')
line[i] = ' ';
@@ -151,7 +151,7 @@
assert(service_to_find);
- /* Make sure the filename of 200 chars abow are more than enought */
+ /* Make sure the filename of 200 chars above are more than enough */
if (strlen(service_to_find) > 50)
{
F_("Service name to long, initng_i_parser can't look for this service!\n");
@@ -172,7 +172,7 @@
service = st_strip_path(service_to_find);
D_("initng_i_parser(%s);\n", service_to_find);
- /* example INITNG_ROOT=/etc/initng service_to_find="deamon/sshd INITNG_EXT=".i" */
+ /* example INITNG_ROOT=/etc/initng service_to_find="daemon/sshd INITNG_EXT=".i" */
/* TRY NO 1, try load "/etc/initng/daemon/sshd.i" */
/* TRY NO 2, try load "/etc/initng/daemon/sshd/sshd.i" */
/* TRY NO 3, try load "/etc/initng/daemon/sshd/default.i" */
@@ -275,7 +275,7 @@
char *file = NULL;
- /* if service is matching, it is set, if service is exeact_match this is set */
+ /* if service is matching, it is set, if service is exact_match this is set */
service_cache_h *match = NULL;
service_cache_h *exact_match = NULL;
@@ -365,8 +365,8 @@
/* add to service db */
if (match && !initng_service_cache_add(match))
{
- /* Problem adding, probably this service name exists allredy,
- * DO NOT EVEN TRY TO UNLOAD EXISTANT! some services my already rely on it or
+ /* Problem adding, probably this service name exists already,
+ * DO NOT EVEN TRY TO UNLOAD EXISTENT! some services my already rely on it or
* we can get here if we processing 'need' option from this service, unloading
* will make watch_for to point on not existing area of memory!
*/
@@ -417,7 +417,7 @@
assert(*to_parse);
assert(watch_for);
- /* for debuging */
+ /* for debugging */
DL_(*to_parse, "parse_service_line:");
/* service test : class { */
@@ -510,7 +510,7 @@
}
}
- DL_(*to_parse, "Parse opt, shud stand direcltly over { char");
+ DL_(*to_parse, "Parse opt, should stand directly over { char");
/* service test : class { */
/* | */
if ((*to_parse)[0] != '{')
@@ -584,11 +584,11 @@
new_service = initng_service_cache_new(name, type);
- /* from here, dont use name anymore, use new_service->name */
+ /* from here, don't use name anymore, use new_service->name */
free(name);
name = NULL;
- /* FROM NOW, we should not free name or father_name, becouse its ADDED, and required */
+ /* FROM NOW, we should not free name or father_name, because its ADDED, and required */
/* check so that it was allocated! */
if (!new_service)
@@ -660,7 +660,7 @@
continue;
}
- /* Bad content, coud not be parsed */
+ /* Bad content, could not be parsed */
/* free and reset */
initng_service_cache_free(new_service);
new_service = NULL;
@@ -683,14 +683,14 @@
{
D_("Found :%s\n", new_service->name);
- /* Just explanation - wi'll erase later (TheLich):
+ /* Just explanation - will erase later (TheLich):
* don't keep services with wildcards in service_cache
* thus there is each separate copy for each service, that
- * was created from wilcard service and now all services
+ * was created from wildcard service and now all services
* in service cache will have unique names (no need in
* pattern search when looking for service). This is because
* of new behaviour of initng parser (adding to cache only that
- * service wich was asked). If we will not do that, then if
+ * service which was asked). If we will not do that, then if
* wildcard service exists in database and we want to add *real*
* service, which matches this wildcard - it will not be added,
* wildcard service will be used instead. (daemon/getty/ * and
@@ -856,18 +856,18 @@
if (!current->opt_name)
continue;
- /* check that option is not marked for a sertain service type */
+ /* check that option is not marked for a certain service type */
if (current->ot && current->ot != type)
continue;
- /* check string lenght of word, this is faster then strcasecmp */
+ /* check string length of word, this is faster then strcasecmp */
if (opt_len != current->opt_name_len)
{
/*F_("Lenght is not correct.\n"); */
continue;
}
- /* finaly, check if opt_name is what we are looking for */
+ /* finally, check if opt_name is what we are looking for */
if (strncmp(current->opt_name, opt_name, opt_len) != 0)
continue;
@@ -1303,7 +1303,7 @@
/* If this value we shud copy is stacked in braces */
if ((*value)[0] == '{')
{
int stack = 1;
@@ -1313,7 +1313,7 @@
#ifndef NOTRIM
JUMP_NSPACES(*value);
#endif
- /* count lenght to the '}' char */
+ /* count length to the '}' char */
while ((*value)[len])
{
if ((*value)[len] == '{')
@@ -1321,7 +1321,7 @@
else if ((*value)[len] == '}')
stack--;
- /* if stack is zero or below, we are standing on a '}' with no excape char before */
+ /* if stack is zero or below, we are standing on a '}' with no escape char before */
if (stack <= 0 && (*value)[len] == '}'
&& (*value)[len - 1] != '\\')
{
@@ -1368,7 +1368,7 @@
/* count the number of tokens */
while ((*value)[len])
{
- /* if this is the ending '"' with no escapechar before */
+ /* if this is the ending '"' with no escape char before */
if ((*value)[len] == '"' && (*value)[len - 1] != '\\')
{
break;
@@ -1396,7 +1396,7 @@
/* else */
DL_(*value, "Non stack or quoted value");
- /* Count lenght */
+ /* Count length */
while ((*value)[len])
{
/* this char is escaped by the char before */
@@ -1406,7 +1406,7 @@
continue;
}
/* If we shud break copying on a space, check this */
if (space_is_new_word == TRUE)
{
DL_(*value, "Space is new word");
@@ -1303,7 +1303,7 @@
continue;
- /* If this value we shud copy is stacked in braces */
+ /* If this value we should copy is stacked in braces */
if ((*value)[0] == '{')
{
@@ -1406,7 +1406,7 @@
continue;
}
- /* If we shud break copying on a space, check this */
+ /* If we should break copying on a space, check this */
if (space_is_new_word == TRUE)
{
Modified: initng/plugins/justbeforeX/initng_jbx.c
==============================================================================
--- initng/plugins/syncron/initng_syncron.c (original)
+++ initng/plugins/syncron/initng_syncron.c Wed Feb 8 08:49:31 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
* Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
*
* This program is free software; you can redistribute it and/or
@@ -34,7 +34,7 @@
#include "initng_syncron.h"
s_entry SYNCRON = { "syncron", STRING, NULL,
- "All services with this same syncron string, can't be started asyncronous."
+ "All services with this same syncron string, can't be started asynchronous."
};
static int check;
@@ -113,7 +113,7 @@
}
initng_service_data_types_add(&SYNCRON);
for (i = 0; g.Argv[i]; i++)
- if (strstr(g.Argv[i], "syncronicly"))
+ if (strstr(g.Argv[i], "synchronously"))
{
check = TRUE;
initng_active_state_add_test(&START_DEP_MET, 10,
@@ -121,8 +121,8 @@
return (TRUE);
}
check = FALSE;
- /* Notice this is only added if we don't have --syncronicly */
- D_("Adding syncron\n");
+ /* Notice this is only added if we don't have --synchronously */
+ D_("Adding synchron\n");
initng_active_state_add_test(&START_DEP_MET, 10,
&check_syncronicly_service);
Modified: initng/plugins/syncron/initng_syncron.h
==============================================================================